pub enum MixerCommand {
AddTrack {
kind: TrackKind,
handle: Arc<TrackHandle>,
},
SetInstrument {
track_id: usize,
instrument: Box<dyn Plugin + Send>,
},
RemoveTrack {
track_id: usize,
},
SetParameter {
track_id: usize,
param_index: usize,
value: f32,
},
CreateClip {
track_id: usize,
start_tick: i64,
length_ticks: i64,
},
UpdateClip {
track_id: usize,
clip_index: usize,
events: Vec<ClipEvent>,
},
UpdateClipPosition {
track_id: usize,
clip_index: usize,
start_tick: i64,
length_ticks: i64,
},
RemoveClip {
track_id: usize,
clip_index: usize,
},
}Variants
AddTrack
SetInstrument
RemoveTrack
SetParameter
CreateClip
Create a new empty clip on a track.
UpdateClip
Replace a clip’s events with edited data from the UI.
UpdateClipPosition
Update a clip’s timeline position and length on the audio thread.
RemoveClip
Remove a clip from a track on the audio thread.