TrackConfig

Struct TrackConfig 

pub struct TrackConfig {
    pub muted: AtomicBool,
    pub soloed: AtomicBool,
    pub armed: AtomicBool,
    pub midi_active: AtomicBool,
    pub volume: AtomicU32,
}
Audio-thread-safe track configuration.

Written by the UI thread, read by the audio thread — all fields are atomic so no locks are needed.

Fields

muted: AtomicBoolsoloed: AtomicBoolarmed: AtomicBoolmidi_active: AtomicBool

Whether this track is currently selected for MIDI input. Only one track should be selected at a time.

volume: AtomicU32

Volume stored as f32 bits in an AtomicU32.

Implementations

Source

impl TrackConfig

pub fn new() -> Self

pub fn get_volume(&self) -> f32

pub fn set_volume(&self, v: f32)

pub fn is_muted(&self) -> bool

pub fn is_soloed(&self) -> bool

pub fn is_armed(&self) -> bool

pub fn is_midi_active(&self) -> bool