pub struct TrackConfig {
pub muted: AtomicBool,
pub soloed: AtomicBool,
pub armed: AtomicBool,
pub midi_active: AtomicBool,
pub volume: AtomicU32,
}Expand description
Audio-thread-safe track configuration.
Written by the UI thread, read by the audio thread — all fields are atomic so no locks are needed.
Fields
muted: AtomicBoolsoloed: AtomicBoolarmed: AtomicBoolmidi_active: AtomicBoolWhether this track is currently selected for MIDI input. Only one track should be selected at a time.
volume: AtomicU32Volume stored as f32 bits in an AtomicU32.
Implementations